@@ -380,8 +380,9 @@ impl Data {
     #[inline]
     pub fn check_reserve(&mut self, size: usize) -> usize {
         let len = self.len();
-        if len > self.capacity().wrapping_sub(size) {
-            self.reserve(len * 2);
+        let cap= self.capacity();
+        if size.wrapping_add(len) > cap {
+            self.reserve(size.wrapping_add(len));
         }
         len
     }
